Changelog
=========

4.7.10001 (2017-11-23)
----------------------

- Initial release as a python package.
  [cerini_j, flohcim, fmichon, jcerini, jymadier, KBurles, mbroquet, nhaye,
  NHaye, nmeucci, oc1n, softime, stimezouaght, tiazma, vpihour]

